@@ -4,7 +4,7 @@
 modname = "rqlcontroller"
 distname = "cubicweb-rqlcontroller"
 
-numversion = (0, 8, 1)
+numversion = (0, 8, 2)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -16,7 +16,7 @@ web = "http://www.cubicweb.org/project/%s" % distname
 __depends__ = {
     "cubicweb": ">= 3.32.2",
 }
-__recommends__ = {"cubicweb-signedrequest": None}
+__recommends__ = {}
 
 classifiers = [
     "Environment :: Web Environment",
